pub enum ComponentType {
Source,
Query,
Reaction,
}Expand description
Component event for tracking lifecycle changes Type of Drasi component
Used for identifying component types in events and monitoring.
Variants