pub enum LogLevel {
Trace,
Debug,
Info,
Warn,
Error,
}Expand description
Log level and log message types for component log streaming Log severity level.
Follows standard log level conventions, from most verbose (Trace) to least verbose (Error).
Variants
Trace
Very detailed tracing information
Debug
Debugging information
Info
General informational messages
Warn
Warning messages
Error
Error messages