pub struct LogMessage {
pub timestamp: DateTime<Utc>,
pub level: LogLevel,
pub message: String,
pub instance_id: String,
pub component_id: String,
pub component_type: ComponentType,
}Expand description
Log level and log message types for component log streaming A structured log message from a component.
Contains the log content along with metadata about when and where the log was generated.
Fields
timestamp: DateTime<Utc>Timestamp when the log was emitted
level: LogLevelSeverity level of the log
message: StringThe log message content
instance_id: StringID of the DrasiLib instance that owns the component
component_id: StringID of the component that emitted the log
component_type: ComponentTypeType of the component (Source, Query, Reaction)
Implementations
Sourceimpl LogMessage
impl LogMessage
Sourcepub fn new(
level: LogLevel,
message: impl Into<String>,
component_id: impl Into<String>,
component_type: ComponentType,
) -> Self
pub fn new( level: LogLevel, message: impl Into<String>, component_id: impl Into<String>, component_type: ComponentType, ) -> Self
Create a new log message with the current timestamp.
Sourcepub fn with_instance(
level: LogLevel,
message: impl Into<String>,
instance_id: impl Into<String>,
component_id: impl Into<String>,
component_type: ComponentType,
) -> Self
pub fn with_instance( level: LogLevel, message: impl Into<String>, instance_id: impl Into<String>, component_id: impl Into<String>, component_type: ComponentType, ) -> Self
Create a new log message with instance ID.