pub struct ByteLexPositionComparator;Expand description
Position comparison trait for per-subscriber replay filtering Default byte-lexicographic position comparator.
Works correctly for any position encoded as big-endian bytes of equal length. For positions of unequal length, shorter bytes compare as less than longer ones with the same prefix.